@@ -1,5 +1,13 @@
 var NAVTREEINDEX15 =
 {
+"group__spa__result.html#gab20d44383dc08a6c9f29126c9ff54a7d":[8,9,8,10,2],
+"group__spa__result.html#gac6610ec8c7368e5c1bf18f92018656f2":[8,9,8,10,7],
+"group__spa__ringbuffer.html":[8,9,8,11],
+"group__spa__ringbuffer.html#ga255dbffcace9c96af41b33e358e1bf1b":[8,9,8,11,5],
+"group__spa__ringbuffer.html#ga48e87cc044b8351f3dcd9d3a66bdf703":[8,9,8,11,2],
+"group__spa__ringbuffer.html#ga636d45b00fa064ed74316528cd21cab5":[8,9,8,11,3],
+"group__spa__ringbuffer.html#ga8d0967ca7c3d8a3dcb39879d46f49cf2":[8,9,8,11,6],
+"group__spa__ringbuffer.html#ga8f1a9c2bb15d923d00803f1dadcccaed":[8,9,8,11,11],
 "group__spa__ringbuffer.html#gaa049c4f76b7818538e2e41adb471d6b4":[8,9,8,11,8],
 "group__spa__ringbuffer.html#gaa333935551d66a9a434227adcb1f3976":[8,9,8,11,9],
 "group__spa__ringbuffer.html#gac988a539e59a52667f90977282898a6c":[8,9,8,11,10],
@@ -241,13 +249,5 @@ var NAVTREEINDEX15 =
 "group__spa__utils__defs.html#gaf5c3a152070995c325caaaf0333269c0":[8,9,8,1,21],
 "group__spa__utils__defs.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e":[8,9,8,1,90],
 "group__spa__utils__defs.html#gaf88c39fbcce246ddc0e78a934dda87cb":[8,9,8,1,59],
-"group__spa__utils__defs.html#gaf8cdb131feb79dfd1d9d1097cb89c052":[8,9,8,1,37],
-"group__spa__utils__defs.html#gaf9f1e071334f25ea8580f2509d17fcdd":[8,9,8,1,44],
-"group__spa__utils__defs.html#gafa109f3532687323c8f8340f18a15220":[8,9,8,1,85],
-"group__spa__utils__defs.html#gafa5449ce6a2352b7966fa923892a46fa":[8,9,8,1,78],
-"group__spa__utils__defs.html#gafd41067bab5e0c66b38886f672702dd4":[8,9,8,1,23],
-"group__spa__utils__defs.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca":[8,9,8,1,50],
-"group__spa__utils__defs.html#gafdd52836cf3dfdc12328615ac44c18e0":[8,9,8,1,14],
-"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d":[8,9,8,1,6,0],
-"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456":[8,9,8,1,6,1]
+"group__spa__utils__defs.html#gaf8cdb131feb79dfd1d9d1097cb89c052":[8,9,8,1,37]
 };
